/*
 *
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.scripting.jython.grizzly;

import java.util.List;

public interface Response {
    /* From the WSGI spec:
    The start_response parameter is a callable accepting two required positional arguments, and one optional argument.
    For the sake of illustration, we have named these arguments status, response_headers, and exc_info,
    but they are not required to have these names, and the application must invoke the start_response callable
    using positional arguments (e.g. start_response(status,response_headers)).

    The status parameter is a status string of the form "999 Message here",
    and response_headers is a list of (header_name,header_value) tuples describing the HTTP response header.
    The optional exc_info parameter is described below in the sections on The start_response() Callable and Error Handling.
    It is used only when the application has trapped an error and is attempting to display an error message to the browser.

    The start_response callable must return a write(body_data) callable that takes one positional parameter:
    a string to be written as part of the HTTP response body.
    (Note: the write() callable is provided only to support certain existing frameworks' imperative output APIs;
    it should not be used by new applications or frameworks if it can be avoided.
    See the Buffering and Streaming section for more details.)

    The exec_info object, if passed, will be a sys.exec_info tuple, used to report errors. It is described at
    http://pyref.infogami.com/sys.exc_info
     */
    public BodyWriter __call__(String status, List<List> response_headers);

    public BodyWriter __call__(String status, List<List> response_headers, List exec_info );
    
}
